/*
 *
 *  $Id: license.h 3890 2011-06-16 06:23:00Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#pragma once

//dicomizator
#define UID_APRIM "METAEMOTION GINKGO RX"
//module
#define SID_APRIM "METAEMOTION_GINKGO_RX"
//sid extension
#define VISUALIZATOR_SID _Std("Visualizator")

#define VISUALIZATOR_VERSION     2
#define VISUALIZATOR_SUB_VERSION 4
#define VISUALIZATOR_SUB_RELEASE 0
#define VISUALIZATOR_CODENAME    "final"
#define VISUALIZATOR_COPYRIGHT   " 2011"
#define VISUALIZATOR_DESCRIPTION _Std("Visualizator Extension")
#define VISUALIZATOR_PROVIDER "MetaEmotion S.L."

